"""
This package provides modules for calibration, detection, alignment,
centroiding, photometry, PSF modeling, and utility functions.
"""

__all__ = [
    "calibration",
    "detection",
    "utils",
    "alignment",
    "alignment",
    "centroid",
    "photometry",
    "psf",
]

from eloy.eloy_version import __version__ as __version__
